@@ -32,14 +32,14 @@ import java.util.Set;
 
 import org.apache.felix.http.base.internal.HttpConfig;
 import org.apache.felix.http.base.internal.handler.ListenerHandler;
-import org.apache.felix.http.base.internal.jakartawrappers.ServletRequestWrapper;
-import org.apache.felix.http.base.internal.jakartawrappers.ServletResponseWrapper;
 import org.apache.felix.http.base.internal.registry.EventListenerRegistry;
 import org.apache.felix.http.base.internal.registry.HandlerRegistry;
 import org.apache.felix.http.base.internal.registry.PerContextHandlerRegistry;
 import org.apache.felix.http.base.internal.runtime.ListenerInfo;
 import org.apache.felix.http.base.internal.service.HttpServiceFactory;
 import org.apache.felix.http.base.internal.service.ServletContextImpl;
+import org.apache.felix.http.jakartawrappers.ServletRequestWrapper;
+import org.apache.felix.http.jakartawrappers.ServletResponseWrapper;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
